==> v4_navigation_engine-0.1.12.tar.gz: android/src/main/kotlin/com/mile/v4_navigation_engine/Navigation/model/POI.kt <==
package com.mile.v4_navigation_engine.model

import android.location.Location
import com.google.gson.Gson
import com.google.gson.internal.LinkedTreeMap
import com.mile.v4_navigation_engine.Navigation.ApplicationRunner
import com.mile.v4_navigation_engine.Navigation.model.Riddle
import com.mile.v4_navigation_engine.R

data class POI(
        val id : String?,
        var arrayDescription : Map<LanguageCode, String>,
        var arrayCoordinates : List<Location>,
        val idCity: String?,
        val idType: Type?,
        val imageUrl: String?,
        val isAutoDirectionAcivated : Boolean?,
        val isBloquant : Boolean?,
        val isDirectionnal : Boolean?,
        var arrayName : Map<LanguageCode, String>,
        val radius: Long,
        val arrayRoute: List<String>?,
        val status : Long?
){
    enum class Type(val id : Long) {
        UNDEFINED(0),
        MONUMENT(1),
        CULTURE(2),
        ENTERTAINMENT(3),
        MERCHANT(4),
        STREET_PLACE_NEIGHBOURHOOD(5),
        RELIGION(6),
        NATURE(7),
        WATER(8),
        DIRECTIONNAL_CLOCKWISE(9),
        DIRECTIONNAL_COUNTERCLOCKWISE(10),
        NO_ANNOTATION(11),
        THEME(12),
        CHALLENGE(13);

        companion object{
            fun get(id : Long) : Type {
                values().forEach {
                    if(id == it.ordinal.toLong())
                        return it
                }
                return UNDEFINED
            }

            fun getDrawableID(id : Long) : Int{
                var drawableID = 0
                when(id.toInt()){
                    0 -> drawableID = R.drawable.pin_undefined
                    1 -> drawableID = R.drawable.pin_culture
                    2 -> drawableID = R.drawable.pin_culture
                    3 -> drawableID = R.drawable.pin_entertainment
                    4 -> drawableID = R.drawable.pin_shop
                    5 -> drawableID = R.drawable.pin_neighbourhood
                    6 -> drawableID = R.drawable.pin_religion
                    7 -> drawableID = R.drawable.pin_nature
                    8 -> drawableID = R.drawable.pin_water
                    11 -> drawableID = R.drawable.pin_undefined
                    12 -> drawableID = R.drawable.pin_themed
                    13 -> drawableID = R.drawable.pin_workout // TODO add sport icon + color icons
                    else -> drawableID = R.drawable.pin_undefined
                }
                return drawableID
            }
        }

    }

    class Direction(val id : Long){
        companion object{
            fun getDrawableID(id : Long?) : Int{
                var drawableID : Int
                when(id?.toInt()){
                    1 -> drawableID = R.drawable.go_straight
                    2 -> drawableID = R.drawable.ic_maneuver_merge_left
                    3 -> drawableID = R.drawable.ic_maneuver_merge_right
                    4 -> drawableID = R.drawable.ic_maneuver_turn_45_left
                    5 -> drawableID = R.drawable.ic_maneuver_turn_45
                    6 -> drawableID = R.drawable.ic_maneuver_turn_75_left
                    7 -> drawableID = R.drawable.ic_maneuver_turn_75
                    8 -> drawableID = R.drawable.ic_maneuver_turn_180_left
                    9 -> drawableID = R.drawable.ic_maneuver_turn_180
                    10 -> drawableID = R.drawable.ic_maneuver_roundabout_straight
                    11 -> drawableID = R.drawable.ic_maneuver_roundabout_sharp_left
                    12 -> drawableID = R.drawable.ic_maneuver_roundabout_sharp_right
                    13 -> drawableID = R.drawable.ic_maneuver_roundabout_left
                    14 -> drawableID = R.drawable.ic_maneuver_roundabout_right
                    15 -> drawableID = R.drawable.ic_maneuver_roundabout_slight_left
                    16 -> drawableID = R.drawable.ic_maneuver_roundabout_slight_right
                    else -> drawableID = R.drawable.go_straight
                }
                return drawableID
            }
        }
    }

    val name : String
        get() {
            return arrayName[ApplicationRunner.appLanguage].toString()
        }

    val description : String
        get() {
            return arrayDescription[ApplicationRunner.appLanguage].toString()
        }

    val mainCoordinates : Location
        get() {
            return arrayCoordinates.first()
        }

    var isSeen = false;
    companion object {
        val ID_FIELD = "id"
        val DESCRIPTION_FIELD = "Description"
        val COORDINATES_FIELD = "GPS"
        val ID_CITY_FIELD = "IdCity"
        val TYPE_ID_FIELD = "Idtype"
        val IMAGE_URL_FIELD = "ImageUrl"
        val AUDO_DIRECTION_ACTIVATED = "IsAutoDirectionActivated"
        val BLOCK_FIELD = "IsBloquant"
        val IS_DIRECTIONNAL_FIELD = "IsDirectionnal"
        val NAME_FIELD = "Name"
        val RANGE_FIELD = "Range"
        val ROUTE_FIELD = "Route"
        val STATUS_FIELD = "Status"

        fun fromFlutter(data: LinkedTreeMap<*,*>): POI {
            //System.out.println(jsonPOI);
            //val data: Map<*, *> = Gson().fromJson(jsonPOI, MutableMap::class.java)

            val arrayNames = HashMap<LanguageCode, String>()
            val arrayDescription = HashMap<LanguageCode, String>()
            val arrayCoordinates = ArrayList<Location>()
            val arrayRoute = ArrayList<String>()

            val id = data[ID_FIELD] as String?
            val idCity = data[ID_CITY_FIELD] as String
            val idType = (data[TYPE_ID_FIELD] as Double).toLong()
            val imageURL = data[IMAGE_URL_FIELD] as String?
            val isAutoDirectionAcivated = data[AUDO_DIRECTION_ACTIVATED] as Boolean?
            val isBloquant = data[BLOCK_FIELD] as Boolean?
            val isDirectionnal = data[IS_DIRECTIONNAL_FIELD] as Boolean?
            val range = (data[RANGE_FIELD] as Double).toLong()
            val status = (data[STATUS_FIELD] as Double).toLong()

            // We fetch values which are in multiple language in each available language
            if(data[NAME_FIELD] != null){
                var dataName  = data[NAME_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayNames[LanguageCode.getLanguageCodeFrom(name.key)] = name.value // We fetch "FR" -> "Champagne" from db, we need to convert "FR" to model LanguageCode
                }
            }

            if(data[DESCRIPTION_FIELD] != null) {
                var dataName = data[DESCRIPTION_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayDescription[LanguageCode.getLanguageCodeFrom(name.key)] = name.value
                }
            }

            val listCoordinatesSnapshot = data[COORDINATES_FIELD] as ArrayList<LinkedTreeMap<String, Double>>
            listCoordinatesSnapshot.forEach {
                var location = Location("provider")
                it.forEach {
                    if(it.key == "Latitude")
                        location.latitude = it.value
                    if(it.key == "Longitude")
                        location.longitude = it.value
                }
                arrayCoordinates.add(location)
            }

            if(data[NAME_FIELD] != null){
                var dataName  = data[NAME_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayRoute.add(name.key)
                }
            }

            return POI(id, arrayDescription, arrayCoordinates, idCity, POI.Type.get(idType), imageURL, isAutoDirectionAcivated, isBloquant, isDirectionnal, arrayNames, range, arrayRoute,status)
        }

    }
}

==> v4_navigation_engine-0.1.19.tar.gz: android/src/main/kotlin/com/mile/v4_navigation_engine/Navigation/model/POI.kt <==
package com.mile.v4_navigation_engine.model

import android.location.Location
import com.google.gson.Gson
import com.google.gson.internal.LinkedTreeMap
import com.mile.v4_navigation_engine.Navigation.ApplicationRunner
import com.mile.v4_navigation_engine.Navigation.model.Riddle
import com.mile.v4_navigation_engine.R

data class POI(
        val id : String?,
        var arrayDescription : Map<LanguageCode, String>,
        var arrayCoordinates : List<Location>,
        val idCity: String?,
        val idType: Type?,
        val imageUrl: String?,
        val isAutoDirectionAcivated : Boolean?,
        val isBloquant : Boolean?,
        val isDirectionnal : Boolean?,
        var arrayName : Map<LanguageCode, String>,
        val radius: Long,
        val arrayRoute: List<String>?,
        val status : Long?
){
    enum class Type(val id : Long) {
        UNDEFINED(0),
        MONUMENT(1),
        CULTURE(2),
        ENTERTAINMENT(3),
        MERCHANT(4),
        STREET_PLACE_NEIGHBOURHOOD(5),
        RELIGION(6),
        NATURE(7),
        WATER(8),
        DIRECTIONNAL_CLOCKWISE(9),
        DIRECTIONNAL_COUNTERCLOCKWISE(10),
        NO_ANNOTATION(11),
        THEME(12),
        CHALLENGE(13);

        companion object{
            fun get(id : Long) : Type {
                values().forEach {
                    if(id == it.ordinal.toLong())
                        return it
                }
                return UNDEFINED
            }

            fun getDrawableID(id : Long) : Int{
                var drawableID = 0
                when(id.toInt()){
                    0 -> drawableID = R.drawable.pin_undefined
                    1 -> drawableID = R.drawable.pin_culture
                    2 -> drawableID = R.drawable.pin_culture
                    3 -> drawableID = R.drawable.pin_entertainment
                    4 -> drawableID = R.drawable.pin_shop
                    5 -> drawableID = R.drawable.pin_neighbourhood
                    6 -> drawableID = R.drawable.pin_religion
                    7 -> drawableID = R.drawable.pin_nature
                    8 -> drawableID = R.drawable.pin_water
                    11 -> drawableID = R.drawable.pin_undefined
                    12 -> drawableID = R.drawable.pin_themed
                    13 -> drawableID = R.drawable.pin_workout // TODO add sport icon + color icons
                    else -> drawableID = R.drawable.pin_undefined
                }
                return drawableID
            }
        }

    }

    class Direction(val id : Long){
        companion object{
            fun getDrawableID(id : Long?) : Int{
                var drawableID : Int
                when(id?.toInt()){
                    1 -> drawableID = R.drawable.go_straight
                    2 -> drawableID = R.drawable.ic_maneuver_merge_left
                    3 -> drawableID = R.drawable.ic_maneuver_merge_right
                    4 -> drawableID = R.drawable.ic_maneuver_turn_45_left
                    5 -> drawableID = R.drawable.ic_maneuver_turn_45
                    6 -> drawableID = R.drawable.ic_maneuver_turn_75_left
                    7 -> drawableID = R.drawable.ic_maneuver_turn_75
                    8 -> drawableID = R.drawable.ic_maneuver_turn_180
                    9 -> drawableID = R.drawable.ic_maneuver_turn_180
                    10 -> drawableID = R.drawable.ic_maneuver_roundabout_straight
                    11 -> drawableID = R.drawable.ic_maneuver_roundabout_sharp_left
                    12 -> drawableID = R.drawable.ic_maneuver_roundabout_sharp_right
                    13 -> drawableID = R.drawable.ic_maneuver_roundabout_left
                    14 -> drawableID = R.drawable.ic_maneuver_roundabout_right
                    15 -> drawableID = R.drawable.ic_maneuver_roundabout_slight_left
                    16 -> drawableID = R.drawable.ic_maneuver_roundabout_slight_right
                    else -> drawableID = R.drawable.go_straight
                }
                return drawableID
            }
        }
    }

    val name : String
        get() {
            return arrayName[ApplicationRunner.appLanguage].toString()
        }

    val description : String
        get() {
            return arrayDescription[ApplicationRunner.appLanguage].toString()
        }

    val mainCoordinates : Location
        get() {
            return arrayCoordinates.first()
        }

    var isSeen = false;
    companion object {
        val ID_FIELD = "id"
        val DESCRIPTION_FIELD = "Description"
        val COORDINATES_FIELD = "GPS"
        val ID_CITY_FIELD = "IdCity"
        val TYPE_ID_FIELD = "Idtype"
        val IMAGE_URL_FIELD = "ImageUrl"
        val AUDO_DIRECTION_ACTIVATED = "IsAutoDirectionActivated"
        val BLOCK_FIELD = "IsBloquant"
        val IS_DIRECTIONNAL_FIELD = "IsDirectionnal"
        val NAME_FIELD = "Name"
        val RANGE_FIELD = "Range"
        val ROUTE_FIELD = "Route"
        val STATUS_FIELD = "Status"

        fun fromFlutter(data: LinkedTreeMap<*,*>): POI {
            //System.out.println(jsonPOI);
            //val data: Map<*, *> = Gson().fromJson(jsonPOI, MutableMap::class.java)

            val arrayNames = HashMap<LanguageCode, String>()
            val arrayDescription = HashMap<LanguageCode, String>()
            val arrayCoordinates = ArrayList<Location>()
            val arrayRoute = ArrayList<String>()

            val id = data[ID_FIELD] as String?
            val idCity = data[ID_CITY_FIELD] as String
            val idType = (data[TYPE_ID_FIELD] as Double).toLong()
            val imageURL = data[IMAGE_URL_FIELD] as String?
            val isAutoDirectionAcivated = data[AUDO_DIRECTION_ACTIVATED] as Boolean?
            val isBloquant = data[BLOCK_FIELD] as Boolean?
            val isDirectionnal = data[IS_DIRECTIONNAL_FIELD] as Boolean?
            val range = (data[RANGE_FIELD] as Double).toLong()
            val status = (data[STATUS_FIELD] as Double).toLong()

            // We fetch values which are in multiple language in each available language
            if(data[NAME_FIELD] != null){
                var dataName  = data[NAME_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayNames[LanguageCode.getLanguageCodeFrom(name.key)] = name.value // We fetch "FR" -> "Champagne" from db, we need to convert "FR" to model LanguageCode
                }
            }

            if(data[DESCRIPTION_FIELD] != null) {
                var dataName = data[DESCRIPTION_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayDescription[LanguageCode.getLanguageCodeFrom(name.key)] = name.value
                }
            }

            val listCoordinatesSnapshot = data[COORDINATES_FIELD] as ArrayList<LinkedTreeMap<String, Double>>
            listCoordinatesSnapshot.forEach {
                var location = Location("provider")
                it.forEach {
                    if(it.key == "Latitude")
                        location.latitude = it.value
                    if(it.key == "Longitude")
                        location.longitude = it.value
                }
                arrayCoordinates.add(location)
            }

            if(data[NAME_FIELD] != null){
                var dataName  = data[NAME_FIELD] as LinkedTreeMap<String, String>?
                dataName?.forEach { name ->
                    arrayRoute.add(name.key)
                }
            }

            return POI(id, arrayDescription, arrayCoordinates, idCity, POI.Type.get(idType), imageURL, isAutoDirectionAcivated, isBloquant, isDirectionnal, arrayNames, range, arrayRoute,status)
        }

    }
}
